from setuptools import setup, find_packages

setup(
    name="rratelimiter",
    version="0.2.0",
    packages=find_packages(),
    install_requires=[
        # list your dependencies here
    ],
    author="Rishabh Prajapati",
    author_email="prajapatirishabh04@gmail.com",
    description="A simple example Python library",
)
